.. _sedatie:

sedatie
#######

"Intoxicaties met antipsychotica geven vaak aanleiding tot depressie van het centraal zenuwstelsel (CZS), zich in eerste instantie uitend in sedatie."

Quote van https://vergiftigingen.info, zoek bijv. Zyprexa

Sederen om gevaar te weren, is vergiftiging van de hersenen om tot een depressie van het CZS zodat men in een toestand van sedatie terecht komt.
Een depressie van het centrale zenuwstelsel kan men een benadeling van de gezondheid noemen, men kan het ook een bedreiging op het leven benoemen.

| 300.4 Met mishandeling wordt gelijkgesteld opzettelijke benadeling van de gezondheid.

| 304.3 indien het misdrijf wordt gepleegd door toediening van voor het leven of de gezondheid schadelijke stoffen.

